@@ -14,14 +14,10 @@
  * SOFTWARE.
  */
 
-extern crate dmntk_common;
-extern crate dmntk_evaluator;
-extern crate dmntk_feel;
-extern crate dmntk_model;
+pub extern crate dmntk_evaluator;
 #[macro_use]
 extern crate lazy_static;
 
 mod workspace;
 
-pub use workspace::deploy_definitions;
-pub use workspace::evaluate_artifact;
+pub use workspace::{deploy_definitions, evaluate_artifact};
