@@ -19,17 +19,14 @@
 //! In the future, the workspaces should be adjusted to store models
 //! for multiple users (multi-user mode).
 
-use {
-  self::errors::*,
-  dmntk_common::{DmntkError, Result},
-  dmntk_feel::{context::FeelContext, values::Value},
-  dmntk_model::model::{Definitions, DmnElement, NamedElement},
-  std::{
-    collections::HashMap,
-    convert::TryFrom,
-    sync::{Arc, Mutex},
-  },
-};
+use self::errors::*;
+use dmntk_evaluator::dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_evaluator::dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::{DmntkError, Result};
+use dmntk_evaluator::dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::Value;
+use dmntk_evaluator::dmntk_recognizer::dmntk_model::model::{Definitions, DmnElement, NamedElement};
+use std::collections::HashMap;
+use std::convert::TryFrom;
+use std::sync::{Arc, Mutex};
 
 lazy_static! {
   static ref WORKSPACES: Arc<Mutex<HashMap<String, Workspace>>> = Arc::new(Mutex::new(HashMap::new()));
@@ -155,7 +152,7 @@ pub fn evaluate_artifact(ctx: &FeelContext, model_tag: &str, artifact_type: &str
 
 /// Errors reported by the workspace.
 mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_evaluator::dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
   /// Errors related with operating on workspaces.
   #[derive(Debug, PartialEq)]
